==> pylucene-9.12.0-src.tar.gz: pylucene-9.12.0/lucene-java-9.12.0/lucene/extensions/src/java/org/apache/pylucene/store/PythonIndexInput.java <==
/* ====================================================================
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

package org.apache.pylucene.store;

import java.io.IOException;
import java.nio.ByteBuffer;
import org.apache.lucene.store.BufferedIndexInput;
import org.apache.lucene.store.IOContext;


public class PythonIndexInput extends BufferedIndexInput {

    private long pythonObject;

    public PythonIndexInput(String resourceDesc)
    {
        super(resourceDesc);
    }

    public PythonIndexInput(String resourceDesc, int bufferSize)
    {
        super(resourceDesc, bufferSize);
    }

    public PythonIndexInput(String resourceDesc, IOContext context)
    {
        super(resourceDesc, context);
    }
    
    public void pythonExtension(long pythonObject)
    {
        this.pythonObject = pythonObject;
    }
    public long pythonExtension()
    {
        return this.pythonObject;
    }

    public void finalize()
        throws Throwable
    {
        pythonDecRef();
    }

    public native void pythonDecRef();

    @Override
    public native PythonIndexInput clone();
    @Override
    public native long length();
    @Override
    public native void close()
        throws IOException;
    @Override
    public native void seekInternal(long pos)
        throws IOException;

    public native byte[] readInternal(int length, long pos)
        throws IOException;

    @Override
    protected void readInternal(ByteBuffer b)
        throws IOException
    {
        byte[] data = readInternal(b.remaining(), getFilePointer());

        System.arraycopy(data, 0, b.array(), b.position(), data.length);
        b.position(b.position() + data.length);
    }
}

==> pylucene-10.0.0-src.tar.gz: pylucene-10.0.0/lucene-java-10.0.0/lucene/extensions/src/java/org/apache/pylucene/store/PythonIndexInput.java <==
/* ====================================================================
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

package org.apache.pylucene.store;

import java.io.IOException;
import java.nio.ByteBuffer;
import org.apache.lucene.store.BufferedIndexInput;
import org.apache.lucene.store.IOContext;
import org.apache.pylucene.ref.PythonObject;
import org.apache.pylucene.ref.PythonObjectManager;

public class PythonIndexInput extends BufferedIndexInput {

    private PythonObject pythonObject;

    public PythonIndexInput(String resourceDesc)
    {
        super(resourceDesc);
    }

    public PythonIndexInput(String resourceDesc, int bufferSize)
    {
        super(resourceDesc, bufferSize);
    }

    public PythonIndexInput(String resourceDesc, IOContext context)
    {
        super(resourceDesc, context);
    }
    
    public void pythonExtension(long pythonObject)
    {
        this.pythonObject = PythonObjectManager.register(pythonObject);
    }
    public long pythonExtension()
    {
        return this.pythonObject.pythonObject;
    }

    @Override
    public native PythonIndexInput clone();
    @Override
    public native long length();
    @Override
    public native void close()
        throws IOException;
    @Override
    public native void seekInternal(long pos)
        throws IOException;

    public native byte[] readInternal(int length, long pos)
        throws IOException;

    @Override
    protected void readInternal(ByteBuffer b)
        throws IOException
    {
        byte[] data = readInternal(b.remaining(), getFilePointer());

        System.arraycopy(data, 0, b.array(), b.position(), data.length);
        b.position(b.position() + data.length);
    }
}
